@@ -132,7 +132,7 @@ glmmbootFit <- function (X, Y, weights = rep(1, NROW(Y)),
                   bootP = double(1),
                   bootLog = double(boot),
                   convergence = integer(1),
-                  DUP = FALSE,
+                  ##DUP = FALSE,
                   PACKAGE = "glmmML"
                   )
         res <- list(coefficients = fit$beta,
@@ -182,7 +182,7 @@ glmmbootFit <- function (X, Y, weights = rep(1, NROW(Y)),
                   bootP = double(1),
                   bootLog = double(boot),
                   convergence = integer(1),
-                  DUP = FALSE,
+                  ##DUP = FALSE,
                   PACKAGE = "glmmML"
                   )
         res <- list(coefficients = NULL,
